pub fn diff(old: &ServerConfig, new: &ServerConfig) -> ConfigDiffExpand description
Compare two configs and produce a diff of what changed
pub fn diff(old: &ServerConfig, new: &ServerConfig) -> ConfigDiffCompare two configs and produce a diff of what changed