pub enum HotReloadError {
Watch(Error),
Io(Error),
Tls(String),
Rustls(String),
Config(ConfigError),
}Expand description
Errors that can occur during hot-reload operations.
Variants
Watch(Error)
File-system watcher could not be created or watch path could not be added.
Io(Error)
An I/O error occurred while reading a certificate or key file.
Tls(String)
The PEM bytes loaded from disk could not be used to build a TLS identity.
Rustls(String)
A rustls::ServerConfig could not be built from the provided creds —
surfaced from amaters_net::tls_acceptor::build_rustls_config.
Config(ConfigError)
The config reload itself reported an error.