pub struct CacheKey(/* private fields */);Expand description
Opaque cache key derived from a blake3 hash of the serialized query.
Implementations
Sourceimpl CacheKey
impl CacheKey
Sourcepub fn from_bytes(data: &[u8]) -> Self
pub fn from_bytes(data: &[u8]) -> Self
Build a cache key by hashing arbitrary bytes with blake3.
Sourcepub fn from_query(query_type: &str, params: &[u8]) -> Self
pub fn from_query(query_type: &str, params: &[u8]) -> Self
Build a composite key from a query type tag and parameter bytes.
The key is blake3(query_type || b':' || params).