pub struct LocalSnapshotUploader { /* private fields */ }Expand description
Local filesystem implementation of SnapshotUploader.
URIs produced by this uploader have the form local://<absolute_path>.
Implementations
Sourceimpl LocalSnapshotUploader
impl LocalSnapshotUploader
Sourcepub fn new(base_path: impl Into<PathBuf>) -> ServerResult<Self>
pub fn new(base_path: impl Into<PathBuf>) -> ServerResult<Self>
Create a new uploader that stores remote snapshots under base_path.
The directory is created if it does not already exist.